@@ -46,6 +46,7 @@
 #include <spot/twa/twagraph.hh>
 #include <spot/twaalgos/simulation.hh>
 #include <spot/twaalgos/split.hh>
+#include <spot/twaalgos/toparity.hh>
 
 enum
 {
@@ -70,10 +71,13 @@ static const argp_option options[] =
       " propositions", 0},
     /**************************************************/
     { nullptr, 0, nullptr, 0, "Fine tuning:", 10 },
-    { "algo", OPT_ALGO, "qp|rec", 0,
-      "choose the parity game algorithm, valid ones are rec (Zielonka's"
-      " recursive algorithm, default) and qp (Calude et al.'s quasi-polynomial"
-      " time algorithm)", 0 },
+    { "algo", OPT_ALGO, "ds|sd", 0,
+      "choose the algorithm for synthesis:\n"
+      " - sd:   split then determinize with Safra (default)\n"
+      " - ds:   determinize (Safra) then split\n"
+      " - lar:  translate to a deterministic automaton with arbitrary"
+      "         acceptance condition, then use LAR to turn to parity,"
+      "         then split", 0 },
     /**************************************************/
     { nullptr, 0, nullptr, 0, "Output options:", 20 },
     { "print-pg", OPT_PRINT, nullptr, 0,
@@ -112,27 +116,29 @@ bool opt_print_pg(false);
 bool opt_real(false);
 bool opt_print_aiger(false);
 
-// FIXME rename options to choose the algorithm
 enum solver
 {
-  QP,
-  REC
+  DET_SPLIT,
+  SPLIT_DET,
+  LAR,
 };
 
 static char const *const solver_args[] =
 {
-  "qp", "quasi-polynomial",
-  "recursive",
+  "detsplit", "ds",
+  "splitdet", "sd",
+  "lar",
   nullptr
 };
 static solver const solver_types[] =
 {
-  QP, QP,
-  REC,
+  DET_SPLIT, DET_SPLIT,
+  SPLIT_DET, SPLIT_DET,
+  LAR,
 };
 ARGMATCH_VERIFY(solver_args, solver_types);
 
-static solver opt_solver = REC;
+static solver opt_solver = SPLIT_DET;
 static bool verbose = false;
 
 namespace
@@ -187,16 +193,21 @@ namespace
   {
     // if the input automaton is deterministic, degeneralize it to be sure to
     // end up with a parity automaton
-    auto dpa = spot::tgba_determinize(spot::degeneralize_tba(split));
+    auto dpa = spot::tgba_determinize(spot::degeneralize_tba(split),
+                                      false, true, true, false);
     dpa->merge_edges();
     if (opt_print_pg)
       dpa = spot::sbacc(dpa);
     spot::colorize_parity_here(dpa, true);
     spot::change_parity_here(dpa, spot::parity_kind_max,
                              spot::parity_style_odd);
-    bool max, odd;
-    dpa->acc().is_parity(max, odd);
-    assert(max && odd);
+    assert((
+      [&dpa]() -> bool
+        {
+          bool max, odd;
+          dpa->acc().is_parity(max, odd);
+          return max && odd;
+        }()));
     assert(spot::is_deterministic(dpa));
     return dpa;
   }
@@ -271,6 +282,12 @@ namespace
       spot::process_timer timer;
       timer.start();
 
+      if (opt_solver == LAR)
+        {
+          trans_.set_type(spot::postprocessor::Generic);
+          trans_.set_pref(spot::postprocessor::Deterministic);
+        }
+
       auto aut = trans_.run(&f);
       if (verbose)
         std::cerr << "translating formula done" << std::endl;
@@ -293,12 +310,63 @@ namespace
           all_outputs &= bdd_ithvar(v);
         }
 
-      auto split = split_2step(aut, all_inputs);
-      if (verbose)
-        std::cerr << "split inputs and outputs done" << std::endl;
-      auto dpa = to_dpa(split);
-      if (verbose)
-        std::cerr << "determinization done" << std::endl;
+      spot::twa_graph_ptr dpa = nullptr;
+      switch (opt_solver)
+        {
+          case DET_SPLIT:
+            {
+              auto tmp = to_dpa(aut);
+              if (verbose)
+                std::cerr << "determinization done\n"
+                  << "dpa has " << tmp->num_states() << " states" << std::endl;
+              tmp->merge_states();
+              if (verbose)
+                std::cerr << "simulation done\n"
+                  << "dpa has " << tmp->num_states() << " states" << std::endl;
+              dpa = split_2step(tmp, all_inputs);
+              if (verbose)
+                std::cerr << "split inputs and outputs done\n"
+                  << "automaton has " << dpa->num_states() << " states"
+                  << std::endl;
+              spot::colorize_parity_here(dpa, true);
+              break;
+            }
+          case SPLIT_DET:
+            {
+              auto split = split_2step(aut, all_inputs);
+              if (verbose)
+                std::cerr << "split inputs and outputs done\n"
+                  << "automaton has " << split->num_states() << " states"
+                  << std::endl;
+              dpa = to_dpa(split);
+              if (verbose)
+                std::cerr << "determinization done\n"
+                  << "dpa has " << dpa->num_states() << " states" << std::endl;
+              dpa->merge_states();
+              if (verbose)
+                std::cerr << "simulation done\n"
+                  << "dpa has " << dpa->num_states() << " states" << std::endl;
+              break;
+            }
+          case LAR:
+            {
+              dpa = split_2step(aut, all_inputs);
+              dpa->merge_states();
+              if (verbose)
+                std::cerr << "split inputs and outputs done\n"
+                  << "automaton has " << dpa->num_states() << " states"
+                  << std::endl;
+              dpa = spot::to_parity(dpa);
+              spot::cleanup_parity_here(dpa);
+              spot::change_parity_here(dpa, spot::parity_kind_max,
+                                       spot::parity_style_odd);
+              if (verbose)
+                std::cerr << "LAR construction done\n"
+                  << "dpa has " << dpa->num_states() << " states" << std::endl;
+              spot::colorize_parity_here(dpa, true);
+              break;
+            }
+        }
       auto owner = complete_env(dpa);
       auto pg = spot::parity_game(dpa, owner);
       if (verbose)
@@ -310,58 +378,33 @@ namespace
           pg.print(std::cout);
           return 0;
         }
-      switch (opt_solver)
-        {
-          case REC:
-            {
-              spot::parity_game::strategy_t strategy[2];
-              spot::parity_game::region_t winning_region[2];
-              pg.solve(winning_region, strategy);
-              if (winning_region[1].count(pg.get_init_state_number()))
-                {
-                  std::cout << "REALIZABLE\n";
-                  if (!opt_real)
-                    {
-                      auto strat_aut =
-                        strat_to_aut(pg, strategy[1], dpa, all_outputs);
 
-                      // output the winning strategy
-                      if (opt_print_aiger)
-                        spot::print_aiger(std::cout, strat_aut);
-                      else
-                        {
-                          automaton_printer printer;
-                          printer.print(strat_aut, timer);
-                        }
-                    }
-                  return 0;
-                }
+      spot::parity_game::strategy_t strategy[2];
+      spot::parity_game::region_t winning_region[2];
+      pg.solve(winning_region, strategy);
+      if (winning_region[1].count(pg.get_init_state_number()))
+        {
+          std::cout << "REALIZABLE\n";
+          if (!opt_real)
+            {
+              auto strat_aut =
+                strat_to_aut(pg, strategy[1], dpa, all_outputs);
+
+              // output the winning strategy
+              if (opt_print_aiger)
+                spot::print_aiger(std::cout, strat_aut);
               else
                 {
-                  std::cout << "UNREALIZABLE\n";
-                  return 1;
+                  automaton_printer printer;
+                  printer.print(strat_aut, timer);
                 }
             }
-          case QP:
-            if (!opt_real)
-              {
-                std::cout << "The quasi-polynomial time algorithm does not"
-                  " implement synthesis yet, use --realizability\n";
-                return 2;
-              }
-            else if (pg.solve_qp())
-              {
-                std::cout << "REALIZABLE\n";
-                return 0;
-              }
-            else
-              {
-                std::cout << "UNREALIZABLE\n";
-                return 1;
-              }
-          default:
-            SPOT_UNREACHABLE();
-            return 2;
+          return 0;
+        }
+      else
+        {
+          std::cout << "UNREALIZABLE\n";
+          return 1;
         }
     }
   };
