@@ -68,9 +68,10 @@
   #endif
 #endif
 
-// BUDDY_API is used for the public API symbols. It either DLL imports
-// or DLL exports (or does nothing for static build) BUDDY_LOCAL is
-// used for non-api symbols.
+/* BUDDY_API is used for the public API symbols. It either DLL imports
+** or DLL exports (or does nothing for static build) BUDDY_LOCAL is
+** used for non-api symbols.
+*/
 #ifdef BUDDY_DLL
   #ifdef BUDDY_DLL_EXPORTS
     #define BUDDY_API BUDDY_HELPER_DLL_EXPORT
@@ -153,6 +154,7 @@ DESCR   {* The fields are \\[\baselineskip] \begin{tabular}{lp{10cm}}
 		       garbage collection. \\
   {\tt varnum}       & number of defined bdd variables \\
   {\tt cachesize}    & number of entries in the internal caches \\
+  {\tt hashsize}     & number of entries in the node hash table \\
   {\tt gbcnum}       & number of garbage collections done until now
   \end{tabular} *}
 ALSO    {* bdd\_stats *}
@@ -166,6 +168,7 @@ typedef struct s_bddStat
    int minfreenodes;
    int varnum;
    int cachesize;
+   int hashsize;
    int gbcnum;
 } bddStat;
 
