@@ -30,6 +30,8 @@
 #include <spot/misc/minato.hh>
 #include <spot/misc/random.hh>
 
+using namespace std::string_literals;
+
 namespace spot
 {
   void acc_cond::report_too_many_sets()
@@ -670,14 +672,25 @@ namespace spot
       }
     // "Acceptance: 0 f" is caught by is_generalized_rabin() above.
     // Therefore is_f() below catches "Acceptance: n f" with n>0.
-    if (code_.is_f()
-        || code_.is_t()
-        || code_.back().sub.op != acc_op::Or)
+    if (code_.is_f() || code_.is_t())
       return false;
 
     auto s = code_.back().sub.size;
     acc_cond::mark_t seen_fin = {};
     acc_cond::mark_t seen_inf = {};
+
+    // generalized Rabin should start with Or, unless
+    // it has a single pair.
+    {
+      auto topop = code_.back().sub.op;
+      if (topop == acc_op::And)
+        // Probably single-pair generalized-Rabin.  Shift the source
+        // by one position as if we had an invisible Or in front.
+        ++s;
+      else if (topop != acc_op::Or)
+        return false;
+    }
+
     // Each pair is the position of a Fin followed
     // by the number of Inf.
     std::map<unsigned, unsigned> p;
@@ -754,14 +767,26 @@ namespace spot
       }
     // "Acceptance: 0 t" is caught by is_generalized_buchi() above.
     // Therefore is_t() below catches "Acceptance: n t" with n>0.
-    if (code_.is_t()
-        || code_.is_f()
-        || code_.back().sub.op != acc_op::And)
+    if (code_.is_t() || code_.is_f())
       return false;
 
     auto s = code_.back().sub.size;
     acc_cond::mark_t seen_fin = {};
     acc_cond::mark_t seen_inf = {};
+
+    // generalized Streett should start with And, unless
+    // it has a single pair.
+    {
+      auto topop = code_.back().sub.op;
+      if (topop == acc_op::Or)
+        // Probably single-pair generalized-Streett.  Shift the source
+        // by one position as if we had an invisible And in front.
+        ++s;
+      else if (topop != acc_op::And)
+        return false;
+    }
+
+
     // Each pairs is the position of a Inf followed
     // by the number of Fin.
     std::map<unsigned, unsigned> p;
@@ -956,7 +981,6 @@ namespace spot
                 const acc_cond::acc_code& rhs)
     {
       auto used = lhs.used_sets() | rhs.used_sets();
-
       unsigned c = used.count();
       unsigned umax = used.max_set();
 
@@ -973,6 +997,54 @@ namespace spot
     }
   }
 
+  std::vector<unsigned>
+  acc_cond::acc_code::symmetries() const
+  {
+    auto used = used_sets();
+    unsigned umax = used.max_set();
+
+    bdd_allocator ba;
+    int base = ba.allocate_variables(umax+2);
+    assert(base == 0);
+    std::vector<bdd> r;
+    for (unsigned i = 0; r.size() < umax; ++i)
+      r.emplace_back(bdd_ithvar(base++));
+    bdd bddcode = to_bdd_rec(&back(), &r[0]);
+    bdd tmp;
+
+    std::vector<unsigned> res(umax);
+    for (unsigned x = 0; x < umax; ++x)
+      res[x] = x;
+
+    for (unsigned x : used.sets())
+      for (unsigned y : used.sets())
+        {
+          if (x >= y)
+            continue;
+          if (res[x] != x)
+            continue;
+
+          {
+            bddPair* p = bdd_newpair();
+            bdd_setpair(p, x, umax + 0);
+            bdd_setpair(p, y, umax + 1);
+            tmp = bdd_replace(bddcode, p);
+            bdd_freepair(p);
+
+            p = bdd_newpair();
+            bdd_setpair(p, umax + 0, y);
+            bdd_setpair(p, umax + 1, x);
+            tmp = bdd_replace(tmp, p);
+            bdd_freepair(p);
+          }
+
+          if (tmp == bddcode)
+            res[y] = x;
+        }
+
+    return res;
+  }
+
   bool acc_cond::is_parity(bool& max, bool& odd, bool equiv) const
   {
     unsigned sets = num_;
@@ -1479,6 +1551,51 @@ namespace spot
       SPOT_UNREACHABLE();
       return {};
     }
+
+    static acc_cond::acc_code
+    force_inf_rec(const acc_cond::acc_word* pos, acc_cond::mark_t rem)
+    {
+      auto start = pos - pos->sub.size;
+      switch (pos->sub.op)
+        {
+        case acc_cond::acc_op::And:
+          {
+            --pos;
+            auto res = acc_cond::acc_code::t();
+            do
+              {
+                auto tmp = force_inf_rec(pos, rem) & std::move(res);
+                std::swap(tmp, res);
+                pos -= pos->sub.size + 1;
+              }
+            while (pos > start);
+            return res;
+          }
+        case acc_cond::acc_op::Or:
+          {
+            --pos;
+            auto res = acc_cond::acc_code::f();
+            do
+              {
+                auto tmp = force_inf_rec(pos, rem) | std::move(res);
+                std::swap(tmp, res);
+                pos -= pos->sub.size + 1;
+              }
+            while (pos > start);
+            return res;
+          }
+        case acc_cond::acc_op::Fin:
+          return acc_cond::acc_code::fin(pos[-1].mark - rem);
+        case acc_cond::acc_op::Inf:
+          return acc_cond::acc_code::inf(pos[-1].mark);
+        case acc_cond::acc_op::FinNeg:
+        case acc_cond::acc_op::InfNeg:
+          SPOT_UNREACHABLE();
+          return {};
+        }
+      SPOT_UNREACHABLE();
+      return {};
+    }
   }
 
   acc_cond::acc_code
@@ -1497,6 +1614,14 @@ namespace spot
     return strip_rec(&back(), rem, missing, false);
   }
 
+  acc_cond::acc_code
+  acc_cond::acc_code::force_inf(mark_t rem) const
+  {
+    if (is_t() || is_f())
+      return *this;
+    return force_inf_rec(&back(), rem);
+  }
+
   acc_cond::mark_t
   acc_cond::acc_code::used_sets() const
   {
@@ -1654,7 +1779,7 @@ namespace spot
             break;
           default:
             throw std::runtime_error
-              (std::string("unknown option for acc_cond::name(): ") + c);
+              ("unknown option for acc_cond::name(): "s + c);
           }
 
     std::ostringstream os;
@@ -2119,4 +2244,62 @@ namespace spot
 
     std::swap(c, *this);
   }
+  int acc_cond::acc_code::fin_one() const
+  {
+    if (empty() || is_f())
+      return -1;
+    const acc_cond::acc_word* pos = &back();
+    do
+      {
+        switch (pos->sub.op)
+          {
+          case acc_cond::acc_op::And:
+          case acc_cond::acc_op::Or:
+            --pos;
+            break;
+          case acc_cond::acc_op::Inf:
+          case acc_cond::acc_op::InfNeg:
+          case acc_cond::acc_op::FinNeg:
+            pos -= 2;
+            break;
+          case acc_cond::acc_op::Fin:
+            return pos[-1].mark.min_set() - 1;
+          }
+      }
+    while (pos >= &front());
+    return -1;
+  }
+
+  acc_cond::mark_t acc_cond::acc_code::fin_unit() const
+  {
+    mark_t res = {};
+    if (empty() || is_f())
+      return res;
+    const acc_cond::acc_word* pos = &back();
+    do
+      {
+        switch (pos->sub.op)
+          {
+          case acc_cond::acc_op::And:
+            --pos;
+            break;
+          case acc_cond::acc_op::Or:
+            pos -= pos->sub.size + 1;
+            break;
+          case acc_cond::acc_op::Inf:
+          case acc_cond::acc_op::InfNeg:
+          case acc_cond::acc_op::FinNeg:
+            pos -= 2;
+            break;
+          case acc_cond::acc_op::Fin:
+            auto m = pos[-1].mark;
+            if (m.count() == 1)
+              res |= m;
+            pos -= 2;
+            break;
+          }
+      }
+    while (pos >= &front());
+    return res;
+  }
 }
