@@ -73,7 +73,7 @@ del a, b, c, T, F, f1, f2, f4, f5
 assert spot.fnode_instances_check()
 
 #----------------------------------------------------------------------
-assert str([x for x in spot.formula('a &b & c')]) == '[a, b, c]'
+assert str([str(x) for x in spot.formula('a &b & c')]) == "['a', 'b', 'c']"
 
 
 def switch_g_f(x):
@@ -142,3 +142,6 @@ def myparse(input):
 # This used to fail, because myparse would return a pointer
 # to pf.f inside the destroyed pf.
 assert myparse('a U b') == spot.formula('a U b')
+
+assert spot.is_liveness('a <-> GFb')
+assert not spot.is_liveness('a & GFb')
